pub struct CampaignStateResponse {
pub actor_count: u64,
pub participation_count: u64,
pub cumulative_participation_reward_amount: Uint128,
pub cumulative_referral_reward_amount: Uint128,
pub locked_balances: Vec<(Denom, Uint128)>,
pub balances: Vec<(Denom, Uint128)>,
pub deposit_amount: Uint128,
pub is_active: bool,
pub is_pending: bool,
}Fields
actor_count: u64participation_count: u64cumulative_participation_reward_amount: Uint128cumulative_referral_reward_amount: Uint128locked_balances: Vec<(Denom, Uint128)>balances: Vec<(Denom, Uint128)>deposit_amount: Uint128is_active: boolis_pending: boolTrait Implementations
Sourceimpl Clone for CampaignStateResponse
impl Clone for CampaignStateResponse
Sourcefn clone(&self) -> CampaignStateResponse
fn clone(&self) -> CampaignStateResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CampaignStateResponse
impl Debug for CampaignStateResponse
Sourceimpl<'de> Deserialize<'de> for CampaignStateResponse
impl<'de> Deserialize<'de> for CampaignStateResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CampaignStateResponse
impl JsonSchema for CampaignStateResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CampaignStateResponse
impl PartialEq for CampaignStateResponse
Sourceimpl Serialize for CampaignStateResponse
impl Serialize for CampaignStateResponse
impl StructuralPartialEq for CampaignStateResponse